==> anywhereSSL_0.3.3.zip: anywhereSSL/include/oninstall.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

function xoops_module_install_anywheressl(&$module) {
	//*************************************************************************/
	// 
	//*************************************************************************/
	// DB󥹥󥹤
	$xoopsDB =& Database::getInstance();
	$awssl_dirname = basename( dirname(dirname(__FILE__)) );

	//*************************************************************************/
	// ͤϿ
	//*************************************************************************/
	$awssl_conf_tbl = $xoopsDB->prefix( 'anywheressl_configs' );
	$sql = "INSERT INTO $awssl_conf_tbl";
	$sql .= " VALUES";
	$sql .= " ( '', 'ssl_url', '" .XOOPS_URL ."' ), ";
	$sql .= " ( '', 'non_ssl_url', '" .XOOPS_URL ."' ), ";
	$sql .= " ( '', 'session_name', 'awssl_session' ), ";
	$sql .= " ( '', 'session_regenerate_id', 'no' )";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	//*************************************************************************/
	// ֥åɽ֤-˹
	//*************************************************************************/
	$newblocks_tbl = $xoopsDB->prefix( 'newblocks' );
	$sql = "UPDATE $newblocks_tbl SET";
	$sql .= " `side` = 5, ";
	$sql .= " `visible` = 1";
	$sql .= " WHERE `name` = 'anywheressl block'";
	$sql .= " AND `dirname` = '$awssl_dirname'";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	//*************************************************************************/
	// ֥åƤΥڡɽ˹
	//*************************************************************************/
	$block_id = 0;
	$sql = "SELECT `bid` FROM $newblocks_tbl";
	$sql .= " WHERE `name` = 'anywheressl block'";
	$sql .= " AND `dirname` = '$awssl_dirname'";
	$result = $xoopsDB->query( $sql );
	while( $myrow = $xoopsDB->fetchArray($result) ) {
		$block_id = intval( $myrow['bid'] );
	}
	$new_blocks_tbl = $xoopsDB->prefix( 'block_module_link' );
	$sql = "UPDATE $new_blocks_tbl SET";
	$sql .= " `module_id` = 0 ";
	$sql .= " WHERE `block_id` = $block_id";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	return true;
}

?>

==> anywhereSSL_0.4.1.zip: anywhereSSL/include/oninstall.inc.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/dev>                       //
//  ------------------------------------------------------------------------ //

if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;

/**
 * xoops_module_install_anywheressl
 * 
 * @param &$module
 * @return void
 */
function xoops_module_install_anywheressl(&$module) {
	//*************************************************************************/
	// 
	//*************************************************************************/
	// DB󥹥󥹤
	$xoopsDB =& Database::getInstance();
	$awssl_dirname = basename( dirname(dirname(__FILE__)) );

	//*************************************************************************/
	// ͤϿ
	//*************************************************************************/
	$session_name = 'awssl' .substr( md5(uniqid(rand(), 1)), 0, 8 ) .'session';
	$awssl_conf_tbl = $xoopsDB->prefix( 'anywheressl_configs' );
	$sql = "INSERT INTO $awssl_conf_tbl";
	$sql .= " VALUES";
	$sql .= " ( '', 'ssl_url', '" .XOOPS_URL ."' ), ";
	$sql .= " ( '', 'non_ssl_url', '" .XOOPS_URL ."' ), ";
	$sql .= " ( '', 'session_name', '$session_name' ), ";
	$sql .= " ( '', 'session_regenerate_id', 'no' ), ";
	$sql .= " ( '', 'login_on_ssl', 'no' )";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	//*************************************************************************/
	// ֥åɽ֤-˹
	//*************************************************************************/
	$newblocks_tbl = $xoopsDB->prefix( 'newblocks' );
	$sql = "UPDATE $newblocks_tbl SET";
	$sql .= " `side` = 5, ";
	$sql .= " `visible` = 1";
	$sql .= " WHERE `name` = 'anywheressl block'";
	$sql .= " AND `dirname` = '$awssl_dirname'";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	//*************************************************************************/
	// ֥åƤΥڡɽ˹
	//*************************************************************************/
	$block_id = 0;
	$sql = "SELECT `bid` FROM $newblocks_tbl";
	$sql .= " WHERE `name` = 'anywheressl block'";
	$sql .= " AND `dirname` = '$awssl_dirname'";
	$result = $xoopsDB->query( $sql );
	while( $myrow = $xoopsDB->fetchArray($result) ) {
		$block_id = intval( $myrow['bid'] );
	}
	$new_blocks_tbl = $xoopsDB->prefix( 'block_module_link' );
	$sql = "UPDATE $new_blocks_tbl SET";
	$sql .= " `module_id` = 0 ";
	$sql .= " WHERE `block_id` = $block_id";
	$result = $xoopsDB->query( $sql );
	if ( ! $result ) {
		return false;
	}

	return true;
}


/**
 * xoops_module_update_anywheressl
 * 
 * @param &$module
 * @return void
 */
function xoops_module_update_anywheressl(&$module) {
	//*************************************************************************/
	// 
	//*************************************************************************/
	// DB󥹥󥹤
	$xoopsDB =& Database::getInstance();
	$awssl_conf_tbl = $xoopsDB->prefix( 'anywheressl_configs' );
	$awssl_enforce_tbl = $xoopsDB->prefix( 'anywheressl_enforce' );

	//*************************************************************************/
	// SSLꤵƤ뤫ǧ
	//*************************************************************************/
	$sql = "SELECT `conf_name` FROM $awssl_conf_tbl";
	$sql .= " WHERE `conf_name` = 'login_on_ssl'";
	$result = $xoopsDB->query( $sql );
	if ( ! $myrow = $xoopsDB->fetchArray($result) ) {
		$sql = "INSERT INTO $awssl_conf_tbl";
		$sql .= " VALUES";
		$sql .= " ( '', 'login_on_ssl', 'no' )";
		$result = $xoopsDB->query( $sql );
		if ( ! $result ) {
			return false;
		}
	}

	//*************************************************************************/
	// anywheressl_enforceơ֥뤬¸ߤ뤫ǧ
	//*************************************************************************/
	$sql = "SHOW FIELDS FROM $awssl_enforce_tbl";
	if ( $xoopsDB->query($sql) ) {
		return true;
	}

	//*************************************************************************/
	// anywheressl_enforceơ֥뤬¸ߤʤϺ
	//*************************************************************************/
	$sql = "CREATE TABLE `$awssl_enforce_tbl` (";
	$sql .= "`fid` smallint(5) unsigned NOT NULL auto_increment,";
	$sql .= "`mid` smallint(5) unsigned NOT NULL default '0',";
	$sql .= "`script_filename` varchar(30) NOT NULL default '',";
	$sql .= "PRIMARY KEY  (`fid`),";
	$sql .= "KEY `mid` (`mid`,`script_filename`)";
	$sql .= ") TYPE=MyISAM ;";
	if ( $xoopsDB->queryF($sql) ) {
		// 
		return true;
	} else {
		// ˼Ԥ
		$msg = "It failed in create anywheressl_enforce table.";
		echo $msg ."<br />\n";
		return false;
	}


}

?>
